@@ -387,6 +387,11 @@ impl Window {
         rx.await?
     }
 
+    #[inline]
+    pub fn builder() -> Builder {
+        Builder::new()
+    }
+
     #[inline]
     pub async fn title(&self) -> Result<String, Error> {
         let hwnd = self.hwnd.clone();
